# This is your system's configuration file (it replaces /etc/nixos/configuration.nix)
{inputs, outputs, lib, config, pkgs, ...}: {
  # You can import other NixOS modules here
  imports = [
    ./modules/networking.nix
    ./modules/gpg.nix
  ];

  nixpkgs = {
    # You can add overlays here
    overlays = [
      outputs.overlays.additions
      outputs.overlays.selfsuper
      outputs.overlays.finalprev
    ];

    # Allow unfree apps
    config.allowUnfree = true;
  };

  # Enable flakes and garbage collection
  nix = {
    settings = {
      experimental-features = "nix-command flakes";
      auto-optimise-store = true;
    };
    gc = {
      automatic = true;
      dates = "weekly";
      options = "--delete-older-than 1w";
    };
  };

  # Set timezone
  time.timeZone = outputs.secrets.timeZone;

  # Select a terminal font
  console = {
    earlySetup = true;
    font = "${pkgs.terminus_font}/share/consolefonts/ter-u22n.psf.gz";
    packages = with pkgs; [ terminus_font ];
    keyMap = "us";
  };

  # Enable git
  programs.git = {
    enable = true;
    lfs.enable = true;
  };

  # Basic firewall settings
  networking.nftables.enable = true;

  # Enable the ZSH shell
  programs.zsh.enable = true;

  # Disable Nano
  programs.nano.enable = false;

  # Disable the HTML documentation link
  documentation = {
    nixos.enable = false;
    info.enable = false;
  };

  # Allow binary firmware
  hardware.enableRedistributableFirmware = true;
}
