{ config, lib, pkgs, modulesPath, ... }: {
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  # Set all boot options
  boot = {
    # Set a kernel version and load/blacklist drivers    
    kernelPackages = pkgs.linuxPackages_zen;
    blacklistedKernelModules = [
      "pcspkr"
    ];               
    kernel.sysctl."vm.max_map_count" = 2147483642;       
    initrd = {
      availableKernelModules = [
        "nvme"
	"xhci_pci"
	"usbhid"
	"usb_storage"
	"sd_mod"
	"sdhci_pci"
      ];
      kernelModules = [
	"kvm-amd"
      ];
    };
  };

  # Mount everything as necessary
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/c0fe8419-88f9-48a0-8c5b-acd4c11f8037";
      fsType = "ext4";
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/BF2B-9AE0";
      fsType = "vfat";
      options = [ "fmask=0022" "dmask=0022" ];
    };
  };

  # Enables DHCP on each ethernet and wireless interface.
  networking.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
